.home-dashboard[data-v-3c84cc2c]{display:flex;flex-direction:column;gap:16px}.hero[data-v-3c84cc2c]{display:flex;justify-content:space-between;align-items:center;padding:20px;border-radius:14px;background:linear-gradient(120deg,#0f6ad81f,#f4b73d1f);border:1px solid rgba(15,106,216,.18)}.hero h1[data-v-3c84cc2c]{margin:0;font-size:26px;color:#12345a}.hero p[data-v-3c84cc2c]{margin:8px 0 0;color:#486486}.kpi-card[data-v-3c84cc2c]{border-radius:12px}.kpi-card .kpi-title[data-v-3c84cc2c]{color:#637a99;font-size:13px}.kpi-card .kpi-value[data-v-3c84cc2c]{margin-top:8px;font-size:26px;font-weight:700;color:#12345a;text-transform:uppercase}.kpi-card .kpi-desc[data-v-3c84cc2c]{margin-top:4px;color:#7f94b1;font-size:12px}.panel[data-v-3c84cc2c]{border-radius:12px}.panel-title[data-v-3c84cc2c]{font-weight:700;color:#12345a}
